# aiodhcpwatcher

<p align="center">
  <a href="https://github.com/bdraco/aiodhcpwatcher/actions/workflows/ci.yml?query=branch%3Amain">
    <img src="https://img.shields.io/github/actions/workflow/status/bdraco/aiodhcpwatcher/ci.yml?branch=main&label=CI&logo=github&style=flat-square" alt="CI Status" >
  </a>
  <a href="https://aiodhcpwatcher.readthedocs.io">
    <img src="https://img.shields.io/readthedocs/aiodhcpwatcher.svg?logo=read-the-docs&logoColor=fff&style=flat-square" alt="Documentation Status">
  </a>
  <a href="https://codecov.io/gh/bdraco/aiodhcpwatcher">
    <img src="https://img.shields.io/codecov/c/github/bdraco/aiodhcpwatcher.svg?logo=codecov&logoColor=fff&style=flat-square" alt="Test coverage percentage">
  </a>
</p>
<p align="center">
  <a href="https://python-poetry.org/">
    <img src="https://img.shields.io/badge/packaging-poetry-299bd7?style=flat-square&logo=data:image/png;base64, " alt="Poetry">
  </a>
  <a href="https://github.com/ambv/black">
    <img src="https://img.shields.io/badge/code%20style-black-000000.svg?style=flat-square" alt="black">
  </a>
  <a href="https://github.com/pre-commit/pre-commit">
    <img src="https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white&style=flat-square" alt="pre-commit">
  </a>
</p>
<p align="center">
  <a href="https://pypi.org/project/aiodhcpwatcher/">
    <img src="https://img.shields.io/pypi/v/aiodhcpwatcher.svg?logo=python&logoColor=fff&style=flat-square" alt="PyPI Version">
  </a>
  <img src="https://img.shields.io/pypi/pyversions/aiodhcpwatcher.svg?style=flat-square&logo=python&amp;logoColor=fff" alt="Supported Python versions">
  <img src="https://img.shields.io/pypi/l/aiodhcpwatcher.svg?style=flat-square" alt="License">
</p>

---

**Documentation**: <a href="https://aiodhcpwatcher.readthedocs.io" target="_blank">https://aiodhcpwatcher.readthedocs.io </a>

**Source Code**: <a href="https://github.com/bdraco/aiodhcpwatcher" target="_blank">https://github.com/bdraco/aiodhcpwatcher </a>

---

Watch for DHCP packets with asyncio

## Installation

Install this via pip (or your favourite package manager):

`pip install aiodhcpwatcher`

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- prettier-ignore-start -->
<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- markdownlint-disable -->
<!-- markdownlint-enable -->
<!-- ALL-CONTRIBUTORS-LIST:END -->
<!-- prettier-ignore-end -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!

## Credits

This package was created with
[Copier](https://copier.readthedocs.io/) and the
[browniebroke/pypackage-template](https://github.com/browniebroke/pypackage-template)
project template.
